@@ -10,7 +10,7 @@ import re
 import uuid
 from typing import Any, Dict, List
 from urllib import parse
-
+import zipfile
 import filetype
 from PIL import Image
 
@@ -126,26 +126,42 @@ def get_filebytes(path_bytes_string):
     return file_bytes, is_file
 
 
-def read_file_to_bytes(file_path):
+def check_file(file_path):
     if not os.path.exists(file_path):
         raise ParamValueError(f"{file_path} file is not exists.")
 
     if not os.path.isfile(file_path):
         raise ParamValueError(f"{file_path} is not a file.")
 
+
+def read_file_to_bytes(file_path):
+    check_file(file_path)
     with open(file_path, "rb") as f:
         bytes_data = f.read()
     return bytes_data
 
 
+def zip_file(file_path, to_zipfile=None, mode="w"):
+    check_file(file_path)
+    to_zipfile = to_zipfile or file_path + "_.zip"
+    zf = zipfile.ZipFile(to_zipfile, mode, zipfile.ZIP_DEFLATED)
+    zf.write(file_path, arcname=os.path.basename(file_path))
+    zf.close()
+    return to_zipfile
+
+
 def sha256(ibytes):
     return hashlib.sha256(ibytes).hexdigest()
 
 
-def timestamp_to_datetime(timestamp):
+def timestamp_to_datetime(timestamp, rlt_type="dt"):
     ts = int(timestamp)
     n = 10 ** (len(str(ts)) - 10)
-    return datetime.datetime.fromtimestamp(int(ts / n))
+    dt = datetime.datetime.fromtimestamp(int(ts / n))
+    if rlt_type == "dt":
+        return dt
+    elif rlt_type == "str":
+        return str(dt)
 
 
 def trx_ts(trx, rlt_type="str"):
@@ -242,7 +258,7 @@ def zip_image(path_bytes_string, kb=IMAGE_MAX_SIZE_KB):
     return img_bytes
 
 
-def split_file_to_trx_objs(path_bytes_string):
+def split_file_to_pieces(path_bytes_string):
     file_bytes, _ = get_filebytes(path_bytes_string)
     total_size = len(file_bytes)
     file_name = filename_init(path_bytes_string)
@@ -257,22 +273,22 @@ def split_file_to_trx_objs(path_bytes_string):
 
     n = math.ceil(total_size / CHUNK_SIZE)
     chunks = [file_bytes[i * CHUNK_SIZE : (i + 1) * CHUNK_SIZE] for i in range(n)]
-    objs = []
+    pieces = []
     for i in range(n):
         ibytes = file_bytes[i * CHUNK_SIZE : (i + 1) * CHUNK_SIZE]
         fileinfo["segments"].append({"id": f"seg-{i+1}", "sha256": sha256(ibytes)})
-        objs.append(
-            FileObj(
+        pieces.append(
+            dict(
                 name=f"seg-{i + 1}",
                 content=ibytes,
                 mediaType="application/octet-stream",
             )
         )
     content = json.dumps(fileinfo).encode()
-    obj = FileObj(content=content, name="fileinfo", mediaType="application/json")
-    objs.insert(0, obj)
-    logger.info(f"{file_name} objs {len(objs)}...")
-    return objs
+    piece = dict(content=content, name="fileinfo", mediaType="application/json")
+    pieces.insert(0, piece)
+    logger.info(f"{file_name} pieces {len(pieces)}...")
+    return pieces
 
 
 def merge_trxs_to_file(file_dir, info, trxs):
@@ -379,7 +395,7 @@ def _get_content(trx_content):
         elif type(imgs) == dict:
             _imgs = [imgs]
         else:
-            raise ParamValueError(403, f"type {type(imgs)} is not supported.")
+            raise ParamValueError(f"type {type(imgs)} is not supported.")
     return _text, _imgs
 
 
@@ -469,15 +485,97 @@ def get_last_trxid_by_chain(trx_id: str, trxs: List, reverse=False):
     return trx_id
 
 
-def get_last_trxid_by_ts(trx_id: str, trxs, reverse=False):  # TODO:这个方法不好，相关调用要改写
-    """get the last trx_id of trxs <type: generator> which if different from given trx_id by trx timestamp"""
-    _ts = datetime.datetime.now() + datetime.timedelta(weeks=-520)
-    _tid = None
-    for trx in trxs:
-        ts = trx_ts(trx, "datetime")
-        if ts > _ts:
-            _ts = ts
-            _tid = trx["TrxId"]
-    if _tid and _tid != trx_id:
-        return _tid, _ts
-    return trx_id, _ts
+def check_sub_strs(string, *subs):
+    """判断 string 中是否存在多个子串中的任意一个"""
+    rlt = False
+    for sub in subs:
+        if sub in string:
+            rlt = True
+            break
+    return rlt
+
+
+def get_seed_url(seed_dict: Dict) -> str:
+    """从新版 seed 中获取 url 形式的 seed url 字符串"""
+    if type(seed_dict) != dict:
+        raise ParamValueError("param type should be dict")
+    url = seed_dict.get("seed")
+    if not url:
+        raise ParamValueError("param value is wrong")
+    return url
+
+
+def _get_seed_query(seed_url: str) -> Dict:
+    """从 seed_url 转换为 字典形式的参数列表"""
+    if not seed_url.startswith("rum://seed?"):
+        raise ParamValueError("invalid Seed URL")
+
+    _q = parse.urlparse(seed_url).query
+    _d = parse.parse_qs(_q)
+
+    # 由于 Python 的实现中，每个 key 的 value 都是 列表，所以做了下述处理
+    # TODO: 如果 u 参数的值有多个，该方法需升级
+    query_dict = {}
+    for k, v in _d.items():
+        if len(v) == 1:
+            query_dict[k] = v[0]
+        else:
+            raise ParamValueError(f"key:{k},value:{v},is not 1:1,update the code")
+    return query_dict
+
+
+def _check_b64str(b64str: str) -> bytes:
+    """对 base64 字符串检查长度，并补位，转换为字节"""
+    l = len(b64str)
+    m = (4 - l % 4) % 4
+    b64byte = b64str.encode() + b"=" * m
+    return b64byte
+
+
+def _b64_url_decode(b64str):
+    b64byte = _check_b64str(b64str)
+    b64byte = base64.urlsafe_b64decode(b64byte)
+    return b64byte
+
+
+def _decode_uuid(b64str):
+    b64byte = _b64_url_decode(b64str)
+    b64uuid = uuid.UUID(bytes=b64byte)
+    return str(b64uuid)
+
+
+def _decode_timestamp(b64str):
+    b64byte = _b64_url_decode(b64str)
+    bigint = int.from_bytes(b64byte, "big")
+    return bigint
+
+
+def _decode_cipher_key(b64str):
+    b64byte = _b64_url_decode(b64str)
+    return b64byte.hex()
+
+
+def _decode_pubkey(b64str):
+    b64byte = _b64_url_decode(b64str)
+    pubkey = base64.standard_b64encode(b64byte).decode()
+    return pubkey
+
+
+def decode_seed_url(url):
+    q = _get_seed_query(url)
+    timestamp = _decode_timestamp(q.get("t"))
+
+    info = {
+        "group_id": _decode_uuid(q.get("g")),
+        "group_name": q.get("a"),
+        "app_key": q.get("y"),
+        "owner": _decode_pubkey(q.get("k")),
+        "created_at": timestamp_to_datetime(timestamp, "str"),
+        "genesis_block_id": _decode_uuid(q.get("b")),
+    }
+    return info
+
+
+def decode_seed(seed):
+    url = get_seed_url(seed)
+    return decode_seed_url(url)
